@@ -1,6 +1,9 @@
 import numpy as np
 
+from compas.datastructures import network_find_cycles
+
 from compas.numerical import connectivity_matrix
+from compas.numerical import face_matrix
 
 
 # ==========================================================================
@@ -17,9 +20,11 @@ class EquilibriumStructure:
         self._connectivity = None
         self._connectivity_free = None
         self._connectivity_fixed = None
+        self._connectivity_faces = None
 
         self._edges = None
         self._nodes = None
+        self._faces = None
 
         self._free_nodes = None
         self._fixed_nodes = None
@@ -28,6 +33,7 @@ class EquilibriumStructure:
         self._node_index = None
         self._edge_index = None
         self._anchor_index = None
+        self._face_node_index = None
 
     @property
     def network(self):
@@ -53,6 +59,27 @@ class EquilibriumStructure:
         if not self.nodes:
             self._nodes = list(self.network.nodes())
 
+    @property
+    def faces(self):
+        """
+        A list with the face keys of the structure.
+        """
+        if not self._faces:
+            self._faces = [cycle[:-1] for cycle in network_find_cycles(self.network)[1:]]
+        return self._faces
+
+    @property
+    def face_node_index(self):
+        """
+        A list with the face keys of the structure.
+        """
+        if not self._face_node_index:
+            face_index = []
+            for face in self.faces:
+                face_index.append([self.node_index[node] for node in face])
+            self._face_node_index = face_index
+        return self._face_node_index
+
     @property
     def node_index(self):
         """
@@ -83,7 +110,7 @@ class EquilibriumStructure:
     @property
     def connectivity(self):
         """
-        The connectivity of the network encoded as a branch-node list of lists.
+        The connectivity of the network encoded as an incidence matrix.
         """
         if self._connectivity is None:
             node_idx = self.node_index
@@ -91,6 +118,15 @@ class EquilibriumStructure:
             self._connectivity = np.array(connectivity_matrix(edges, "list"), dtype=np.float64)
         return self._connectivity
 
+    @property
+    def connectivity_faces(self):
+        """
+        The connectivity of the face cycles of a network encoded as as matrix.
+        """
+        if self._connectivity_faces is None:
+            self._connectivity_faces = face_matrix(self.face_node_index, rtype="array")
+        return self._connectivity_faces
+
     @property
     def connectivity_fixed(self):
         """
