@@ -1,9 +1,9 @@
 from .state import *  # noqa F403
 from .helpers import *  # noqa F403
 from .goal import *  # noqa F403
-from .nodegoal import *  # noqa F403
-from .edgegoal import *  # noqa F403
-from .networkgoal import *  # noqa F403
+from .node import *  # noqa F403
+from .edge import *  # noqa F403
+from .network import *  # noqa F403
 
 
 __all__ = [name for name in dir() if not name.startswith('_')]
