@@ -1,6 +1,8 @@
 from .node import *  # noqa F403
 from .point import *  # noqa F403
 from .coordinates import *  # noqa F403
+from .normal import *  # noqa F403
+from .tangent import *  # noqa F403
 from .line import *  # noqa F403
 from .segment import *  # noqa F403
 from .plane import *  # noqa F403
