@@ -10,18 +10,22 @@ import jax.tree_util as jtu
 # ==========================================================================
 
 class OptimizationRecorder(Data):
+    """A recorder that stores data during the optimization process.
+    """
     def __init__(self, optimizer=None):
         self.optimizer = optimizer
-        self.history = []
-
-    def record(self, value):
-        self.history.append(value)
+        self.history_names = ("q", "xyz_fixed", "loads")
+        self.history = {name: [] for name in self.history_names}
 
     def __call__(self, xk, *args, **kwargs):
         if self.optimizer:
             xk = self.optimizer.parameters_fdm(xk)
         self.record(xk)
 
+    def record(self, parameters):
+        for parameter, name in zip(parameters, self.history_names):
+            self.history[name].append(parameter)
+
     @property
     def data(self):
         data = {}
