@@ -1,4 +1,4 @@
-from .network import *  # noqa F403
+from .network_artist import *  # noqa F403
 from .viewer import *  # noqa F403
 from .register import register_artists
 
